<?php
// 		  File : multiflex4_admin.php
// Description : Used for the admin page -> Multiflex-4 Theme Options
//     Version : 1.0
// 		Author : Peter 'Toxane' Michael
// 	Author URI : http://www.flowdrops.com

class multiflex4
{
	
	function init()
	{
		add_action('admin_menu', array('multiflex4', 'addAdminPage'));
	} // function init
	
	function addAdminPage()
	{
		add_theme_page( ('Multiflex-4&nbsp;Theme&nbsp;Options'), ('Multiflex-4&nbsp;Theme&nbsp;Options'), 'edit_themes', basename(__FILE__), array('multiflex4','displayAdminPage') );
	} // function addAdminPage
	
	function getPages()
	{
		global $wpdb ;
		if (function_exists('wp_list_bookmarks'))
		{
			// Wordpress Version 2.1 or greater
			$results = $wpdb->get_results("SELECT ID, post_title FROM $wpdb->posts WHERE post_type='page' AND post_parent=0 ORDER BY post_title");
		}
		else
		{
			$results = $wpdb->get_results("SELECT ID, post_title FROM $wpdb->posts WHERE post_status='static' AND post_parent=0 ORDER BY post_title");
		}
		return $results ;
	} // function getPages()
	
	function getPageIDs()
	{
		$sitePages = multiflex4::getPages();
		$pageIDs = array();
		$i = 0;
		foreach($sitePages as $sitePage)
		{
			$pageIDs[$i] = $sitePage->ID;
			$i++;
		}
		return $pageIDs;
	} // function getPageIDs()
	
	function selectExcludePages($sitePages, $excludePages)
	{
		$pagesToExclude = array_diff($sitePages, $excludePages); 
		return $pagesToExclude;
	} // function selectExcludePages($sitePages, $excludePages)
			
	function saveOptions()
	{
		check_admin_referer('multiflex4');
		
		$multiflexShowHomeLink = $_POST['multiflexShowHomeLink'];
		$multiflexHeaderLinks_Order = $_POST['multiflexHeaderLinks_Order'];
		$multiflexHeaderLinks_Pages = multiflex4::selectExcludePages(multiflex4::getPageIDs(), $_POST['multiflexHeaderLinks_Pages']);
		$multiflexTopNavBar_Order = $_POST['multiflexTopNavBar_Order'];
		$multiflexTopNavBar_Pages = multiflex4::selectExcludePages(multiflex4::getPageIDs(), $_POST['multiflexTopNavBar_Pages']);
		$multiflexShowSubmenus = $_POST['multiflexShowSubmenus'];
		
		$options = array
		(
			'multiflexShowHomeLink' => $multiflexShowHomeLink,
			'multiflexHeaderLinks_Order' => $multiflexHeaderLinks_Order,
			'multiflexHeaderLinks_Pages' => implode(',', $multiflexHeaderLinks_Pages),
			'multiflexTopNavBar_Order' => $multiflexTopNavBar_Order,
			'multiflexTopNavBar_Pages' => implode(',', $multiflexTopNavBar_Pages),
			'multiflexShowSubmenus' => $multiflexShowSubmenus
		);

		update_option('multiflexParameters', $options);
		return true;		
	} // function updateOptions
	
	function resetOptions()
	{
		check_admin_referer('multiflex4');
		delete_option('multiflexParameters');
		return true;
	} // function resetOptions()
	
	function defaultOptions()
	{
		return array
		(
			'multiflexShowHomeLink' => 1,
			'multiflexHeaderLinks_Order' => 'menu_order',
			'multiflexHeaderLinks_Pages' => '',
			'multiflexTopNavBar_Order' => 'menu_order',
			'multiflexTopNavBar_Pages' => '',
			'multiflexShowSubmenus' => 'checked'
		);
	} // function defaultOptions()
	
	function radioButton( $var, $description = "", $value = "", $selected="" )
	{
		if( $selected == $value ) { $extra = "checked=\"true\""; }
  		echo "<label><input name=\"$var\" id=\"$var\" type=\"radio\" value=\"$value\" $extra /> $description</label><br />\n" ;
	} // function radioButton( $var, $description = "", $value = "", $selected="" )
	
	function displayAdminPage()
	{
		if ( $_POST['saveMultiflexOptions'] )
		{
			if ( multiflex4::saveOptions() )
			{
				echo "<div id=\"message\" class=\"updated fade\"><p><strong>Theme Options sucessfully saved.</strong></p></div>\n" ;
			}
			else
			{
				echo "<div id=\"message\" class=\"error fade\"><p><strong>Oops! An error occured. Theme Options are NOT saved!</strong></p></div>\n" ;
			}
		}
		
		if ( $_POST['resetMultiflexOptions'] )
		{
			if ( multiflex4::resetOptions() )
			{
				echo "<div id=\"message\" class=\"updated fade\"><p><strong>Theme Options sucessfully reset.</strong></p></div>\n" ;
			}
			else
			{
				echo "<div id=\"message\" class=\"error fade\"><p><strong>Oops! An error occured. Theme Options are NOT reset!</strong></p></div>\n" ;
			}
		}
		
		// Style a little bit
		echo "<style type=\"text/css\">\n" ;
		echo "img {float:right; display:box; border:1px solid #ccc; margin-left:10px; clear:both;}\n" ;
		echo "div.divider {border-top:1px solid #ccc; margin-top:15px; clear:both;}\n" ;
		echo "</style>\n" ;
		
		// Page
		echo "<div class=\"wrap\">\n" ;
		echo "<h2>Multiflex-4 Theme Options</h2>\n" ;
		echo "<p>Please set the options below to style the Multiflex-4 Theme according to your needs.</p>\n" ;
		// Page : Form
		echo "<form method=\"post\" action=\"\">\n" ;
		if ( function_exists('wp_nonce_field') ) wp_nonce_field('multiflex4');
		echo "\n" ;
				
		// Get the settings
		$currentSettings = get_settings('multiflexParameters');
		
		// In case this is the first call, there are no settings. We create them now
		if ( !$currentSettings )
		{
			$currentSettings = multiflex4::defaultOptions() ;
			update_option('multiflexParameters', $currentSettings) ;
		}
		
		// Get the Pages
		$sitePages = multiflex4::getPages();
		
		// Options : Show Home Link
		echo "<h3>Home Link</h3>\n" ;
		echo "<p>Choose if you want to have the 'Home' Link as first option in the navigation bar.</p>\n" ;
		echo "<input type=\"checkbox\" name=\"multiflexShowHomeLink\" value=\"1\" checked=\"checked\" /> Show Home Link\n" ;
		echo "<div class=\"divider\"></div>\n" ;
		
		// Options : Header Navigation Links
		echo "<h3>Header Navigation Links</h3>\n" ;
		echo "<img src=\"". get_bloginfo('template_url') . "/admin/img/headerlinks.png\" alt=\"Header Navigation Links\" />\n" ;
		echo "<p>These are the header navigation links. They appear on the top right corner of every page. Uncheck any page to hide the corresponding link :</p>\n" ;
		$multiflexHeaderLinks_Pages = explode(',', $currentSettings['multiflexHeaderLinks_Pages']);
		foreach ( $sitePages as $sitePage )
		{
			echo "<input type=\"checkbox\" name=\"multiflexHeaderLinks_Pages[]\" value=\"" . $sitePage->ID . "\"";
			if(!in_array($sitePage->ID, $multiflexHeaderLinks_Pages)) { echo ' checked="checked"'; }
			echo " /> <a href=\"" . get_permalink($sitePage->ID) . "\">" . $sitePage->post_title . "</a><br />\n" ;
		}
		echo "<input type=\"hidden\" name=\"multiflexHeaderLinks_Pages[]\" value=\"-1\" checked=\"checked\" />\n" ;
		echo "<h4>Page Order :</h4>\n" ;
		multiflex4::radioButton( "multiflexHeaderLinks_Order", "Default", "menu_order", $currentSettings['multiflexHeaderLinks_Order'] ) ;
		multiflex4::radioButton( "multiflexHeaderLinks_Order", "Page Title", "post_title", $currentSettings['multiflexHeaderLinks_Order'] ) ;
		multiflex4::radioButton( "multiflexHeaderLinks_Order", "Date Created", "post_date", $currentSettings['multiflexHeaderLinks_Order'] ) ;
		echo "<div class=\"divider\"></div>\n" ;
		
		// Options : Top Navigation Bar
		echo "<h3>Top Navigation Bar</h3>\n" ;
		echo "<img src=\"". get_bloginfo('template_url') . "/admin/img/navbar.png\" alt=\"Top Navigation Bar\" />\n" ;
		echo "<p>This is the main navigation bar. Uncheck any page to hide the corresponding link :</p>\n" ;
		$multiflexTopNavBar_Pages = explode(',', $currentSettings['multiflexTopNavBar_Pages']);
		foreach ( $sitePages as $sitePage )
		{
			echo "<input type=\"checkbox\" name=\"multiflexTopNavBar_Pages[]\" value=\"" . $sitePage->ID . "\"";
			if(!in_array($sitePage->ID, $multiflexTopNavBar_Pages)) { echo ' checked="checked"'; }
			echo " /> <a href=\"" . get_permalink($sitePage->ID) . "\">" . $sitePage->post_title . "</a><br />\n" ;
		}
		echo "<input type=\"hidden\" name=\"multiflexTopNavBar_Pages[]\" value=\"-1\" checked=\"checked\" />\n" ;
		echo "<h4>Page Order :</h4>\n" ;
		multiflex4::radioButton( "multiflexTopNavBar_Order", "Default", "menu_order", $currentSettings['multiflexTopNavBar_Order'] ) ;
		multiflex4::radioButton( "multiflexTopNavBar_Order", "Page Title", "post_title", $currentSettings['multiflexTopNavBar_Order'] ) ;
		multiflex4::radioButton( "multiflexTopNavBar_Order", "Date Created", "post_date", $currentSettings['multiflexTopNavBar_Order'] ) ;
		echo "<div class=\"divider\"></div>\n" ;
		
		// Options : Submenus
		echo "<h3>Submenus</h3>\n" ;
		echo "<p>You can enable/disable the submenus here :</p>" ;
		echo "<img src=\"". get_bloginfo('template_url') . "/admin/img/submenus.png\" alt=\"Submenus\" />\n" ;
		echo "<input name=\"multiflexShowSubmenus\" type=\"checkbox\" value=\"checked\"" .$currentSettings['multiflexShowSubmenus']. "\" /> Show Submenus\n" ;
		echo "<div class=\"divider\"></div>\n" ;
		
		// Options : Save
		echo "<p>Click on 'Update Theme Options' to save all your selected settings.</p>" ;
		echo "<input type=\"hidden\" name=\"saveMultiflexOptions\" value=\"1\" />\n" ;
		echo "<p class=\"submit\"><input type=\"submit\" value=\"" . __('Update Theme Options') . "\"/></p>\n" ;
		echo "</form>\n" ;
		echo "<div class=\"divider\"></div>\n" ;
		
		// Options : Save
		echo "<form method=\"post\" action=\"\">\n" ;
		if ( function_exists('wp_nonce_field') ) wp_nonce_field('multiflex4');
		echo "\n" ;
		echo "<h3>Reset Theme Options</h3>\n" ;
		echo "<p>Click on 'Reset Theme Options' to reset all settings.</p>" ;
		echo "<input type=\"hidden\" name=\"resetMultiflexOptions\" value=\"1\" />\n" ;
		echo "<p class=\"submit\"><input type=\"submit\" value=\"" . __('Reset Theme Options') . "\"/></p>\n" ;
		echo "</form>\n" ;
		echo "<div class=\"divider\"></div>\n" ;
		
		// Footer
		echo "<h3>The Bottom Line</h3>\n" ;
		echo "<p>The Original Multiflex Series By Gerhard : <a href=\"http://1234.info/\" target=\"_blank\">1234.info</a> &bull; This Fabulous Wordpress Theme Port : <a href=\"http://www.flowdrops.com/\" target=\"_blank\">Peter 'Toxane' Michael</a></p>\n" ;
				
	} // function displayAdminPage
	
} // class Multiflex4

multiflex4::init();

?>